@@ -1,12 +1,20 @@
-/*
- * (C) Copyright 1996-2016 ECMWF.
- * 
- * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
- * granted to it by virtue of its status as an intergovernmental organisation nor
- * does it submit to any jurisdiction.
- */
+/******************************** LICENSE ********************************
+
+ Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at 
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+
+ ******************************** LICENSE ********************************/
 
 /*! \file Polyline.cc
     \brief Implementation of polyline graphics class (template).
@@ -150,11 +158,24 @@ void Polyline::newHole(const Polyline& poly)
 	}
 }
 
+
+struct ReprojectHelper
+{
+	ReprojectHelper(const Transformation& transformation) : transformation_(transformation) {}
+	const Transformation& transformation_;
+	bool operator()(PaperPoint& point) {
+		return !transformation_.fast_reproject(point.x_, point.y_);
+	}
+};
+
 void Polyline::reproject(const Transformation& transformation)
 {
-	for (MagLine::iterator point = polygon_.outer().begin(); point != polygon_.outer().end(); ++point) {
-		transformation.fast_reproject(point->x_, point->y_);
-	}
+
+	MagLine::iterator from = std::remove_if (polygon_.outer().begin(), polygon_.outer().end(), ReprojectHelper(transformation));
+	polygon_.outer().erase(from, polygon_.outer().end());
+
+	
+
 // Now the holes!
 	for (Holes::iterator hole = polygon_.inners().begin(); hole != polygon_.inners().end(); ++hole)  {
 		for (MagLine::iterator h = hole->begin(); h != hole->end(); ++h) {
