@@ -1,22 +1,12 @@
-/******************************** LICENSE ********************************
-
-
- Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
- 
- Licensed under the Apache License, Version 2.0 (the "License"); 
- you may not use this file except in compliance with the License. 
- You may obtain a copy of the License at 
- 
- 	http://www.apache.org/licenses/LICENSE-2.0
- 
- Unless required by applicable law or agreed to in writing, software 
- distributed under the License is distributed on an "AS IS" BASIS, 
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
- See the License for the specific language governing permissions and 
- limitations under the License.
-
-
- ******************************** LICENSE ********************************/
+/*
+ * (C) Copyright 1996-2016 ECMWF.
+ * 
+ * This software is licensed under the terms of the Apache Licence Version 2.0
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
+ * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * granted to it by virtue of its status as an intergovernmental organisation nor
+ * does it submit to any jurisdiction.
+ */
 
 /*! \file BinaryDriver.cc
     \brief Implementation of BinaryDriver.
@@ -301,12 +291,16 @@ void BinaryDriver::renderWindArrow(const Arrow &arrow) const
         for(int pts=0;pts<no;pts++)
         {
           const double x = arr->x_;
-	  out_.write((char *)(&x), sizeof(double));
+          out_.write((char *)(&x), sizeof(double));
           const double y = arr->y_;
-	  out_.write((char *)(&y), sizeof(double));
+          out_.write((char *)(&y), sizeof(double));
           const PaperPoint p = arr->point_;
-	  out_.write((char *)(&p), sizeof(PaperPoint));
-	  ++arr;
+          const double ax = p.x();
+          out_.write((char *)(&ax), sizeof(double));
+          const double ay = p.y();
+          out_.write((char *)(&ay), sizeof(double));
+//          out_.write((char *)(&p), sizeof(PaperPoint));
+          ++arr;
         }
 }
 
@@ -361,12 +355,16 @@ void BinaryDriver::renderWindFlag(const Flag &flag) const
         for(int pts=0;pts<no;pts++)
         {
           const double x = fla->x_;
-	  out_.write((char *)(&x), sizeof(double));
+          out_.write((char *)(&x), sizeof(double));
           const double y = fla->y_;
-	  out_.write((char *)(&y), sizeof(double));
+          out_.write((char *)(&y), sizeof(double));
           const PaperPoint p = fla->point_;
-	  out_.write((char *)(&p), sizeof(PaperPoint));
-	  ++fla;
+          const double ax = p.x();
+          out_.write((char *)(&ax), sizeof(double));
+          const double ay = p.y();
+          out_.write((char *)(&ay), sizeof(double));
+//          out_.write((char *)(&p), sizeof(PaperPoint));
+          ++fla;
         }
 }
 
