@@ -1,12 +1,20 @@
-/*
- * (C) Copyright 1996-2016 ECMWF.
- * 
- * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
- * granted to it by virtue of its status as an intergovernmental organisation nor
- * does it submit to any jurisdiction.
- */
+/******************************** LICENSE ********************************
+
+ Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at 
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+
+ ******************************** LICENSE ********************************/
 
 /*! \file CellShading.cc
     \brief Implementation of the Template class CellShading.
@@ -74,14 +82,9 @@ void CellShading::operator()(IsoPlot* iso, MatrixHandler& data, BasicGraphicsObj
 	double height =  parent.absoluteHeight(); // in cm
 	shading_ = "grid";
 
-
-
 	PaperPoint middle((maxc-minc)/2, (maxr-minr)/2);
 
-
-
-
-
+	adaptive_ = false;
 	shading_ = "cell";
 	MagLog::debug() << "minx="   << minc << endl;
 	MagLog::debug() << "maxx="   << maxc << endl;
@@ -110,15 +113,15 @@ void CellShading::operator()(IsoPlot* iso, MatrixHandler& data, BasicGraphicsObj
 	double distance_plot = projection.distance(point, point1);
 	double distance_data = projection.distance(point, nextdata);
 
-
 	if ( magCompare(resolution_method_, "adaptive" ) ) {
 
 		if (   distance_plot < distance_data ) {
 			iso->isoline(data, parent);
-			cout << "Grid Shading" << endl;
+			//cout << "Grid Shading" << endl;
 			MagLog::info() << "Magics will use grid shading" << endl;
+			adaptive_ = true;
+			return;
 		}
-		return ;
 	}
 	
 	Image* image = new Image();
@@ -139,16 +142,13 @@ void CellShading::operator()(IsoPlot* iso, MatrixHandler& data, BasicGraphicsObj
 		lat -= stepr;
 	}
 	
-	
     ColourTable table;
     vector<Colour>::const_iterator colour = colours_.begin();
     for (int i = 0; i <= *max_element(image->begin(), image->end()); i++)
     {
     	table.push_back(*colour);
-
     	if ( ++colour == colours_.end() ) colour = colours_.begin();
 	}
-	
 
 	PaperPoint pp(minc, maxr);
 	image->setOrigin(pp);
@@ -157,14 +157,13 @@ void CellShading::operator()(IsoPlot* iso, MatrixHandler& data, BasicGraphicsObj
 	image->setHeight(maxr-minr);
 	image->setColourTable(table);
 
-	
 	parent.push_back(image);
 }
+
 DumpShading::DumpShading()
 {
 }
 
-
 DumpShading::~DumpShading()
 {
 }
@@ -183,8 +182,6 @@ void DumpShading::operator()( IsoPlot*,MatrixHandler& data, BasicGraphicsObjectC
 	Image* image = new Image();
 	image->set(data.rows(), data.columns());
 
-
-
 	for ( int row = 0; row < data.rows(); row++) {
 
 		for ( int column = 0; column < data.columns(); column++) {
@@ -195,7 +192,6 @@ void DumpShading::operator()( IsoPlot*,MatrixHandler& data, BasicGraphicsObjectC
 
 	}
 
-
     ColourTable table;
     vector<Colour>::const_iterator colour = colours_.begin();
     for (int i = 0; i <= *max_element(image->begin(), image->end()); i++)
@@ -204,7 +200,6 @@ void DumpShading::operator()( IsoPlot*,MatrixHandler& data, BasicGraphicsObjectC
     	if ( ++colour == colours_.end() ) colour = colours_.begin();
 	}
 
-
 	PaperPoint pp(minc, maxr);
 	image->setOrigin(pp);
 	MagLog::debug() << "origin--->" << pp << endl;
@@ -219,7 +214,6 @@ void DumpShading::operator()( IsoPlot*,MatrixHandler& data, BasicGraphicsObjectC
 bool CellShading::prepare(const LevelSelection& levels, const ColourTechnique& technique)
 {
 	// First Interval ...
-	
 	map_.clear();
 	colours_.clear();
 	map_[Interval(INT_MIN, levels.front())] = 0;
@@ -237,7 +231,6 @@ bool CellShading::prepare(const LevelSelection& levels, const ColourTechnique& t
 
 void  CellShading::visit(LegendVisitor& node, const ColourTechnique&)
 {
-	
 	for ( IntervalMap<int>::const_iterator interval = map_.begin(); interval != map_.end(); ++interval) {
 	   
 	   Polyline* box = new Polyline();
@@ -247,24 +240,15 @@ void  CellShading::visit(LegendVisitor& node, const ColourTechnique&)
 	   // We ignore the first and the last entries: no interest in the legend!  
 	   if (interval->second == 0) continue;
 	   if (interval->second == int(map_.size()-1)) continue;
-	   
-	   
+
 	   box->setFilled(true);
 	   box->setFillColour(colours_[interval->second]);
 	   		
-	   FillShadingProperties* shading = new FillShadingProperties();
-	    	    
-	  
-	          
+	   FillShadingProperties* shading = new FillShadingProperties();	          
 	   box->setShading(shading);
-
-
-	   
 	   node.add(new BoxEntry(min, max, box));	        
 	}
-
 	node.last();
-
 }
 
 
@@ -278,17 +262,18 @@ void CellShading::print(ostream& out)  const
 }
 
 
-
-
 void  CellShading::colour(double val, Colour& colour)
 {
 	colour = this->colours_[this->map_.find(val, 0)];
 }
+
+
 CellArray* CellShading::array(MatrixHandler& matrix, IntervalMap<int>& range,
 		const Transformation& transformation, int width, int height,
 		float resolution, const string& technique)
 {
-
-		return new GridArray(matrix, range, transformation, width, height, resolution, "middle");
-
+		if  ( adaptive_ )
+			return new GridArray(matrix, range, transformation, width, height, resolution, "middle");
+		else 
+			return 0;
 }
