@@ -1,12 +1,20 @@
-/*
- * (C) Copyright 1996-2016 ECMWF.
- * 
- * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
- * granted to it by virtue of its status as an intergovernmental organisation nor
- * does it submit to any jurisdiction.
- */
+/******************************** LICENSE ********************************
+
+ Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+ http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
+
+ ******************************** LICENSE ********************************/
 
 /*! \file IsoPlot.cc
  \brief Implementation of the Template class IsoPlot.
@@ -255,21 +263,7 @@ public:
             return;
         Cell* cell;
         vector<PaperPoint> points;
-        /*
-        if ( column1_ == column2_ && row1_ == row2_ ) {
-            cell = (*parent_)(row1_, column1_);
-            points.push_back(PaperPoint(cell->column(0), cell->row(0)));
-            points.push_back(PaperPoint(cell->column(1), cell->row(0)));
-            points.push_back(PaperPoint(cell->column(1), cell->row(2)));
-            points.push_back(PaperPoint(cell->column(0), cell->row(2)));
-
-
-
-
-            push_back(index, points);
-            return;
-         }
-         */
+      
 
         // bottom
         for (int column = column1_; column <= column2_; column++) {
@@ -1240,6 +1234,8 @@ void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
            range.insert(make_pair(Interval(levels_.back(), levels_.back()+epsilon), r-1));
        CellArray* array = shading_->array(data, range, transformation, parent.widthResolution(), parent.heightResolution(),
             resolution_, technique_);
+       if (!array)
+            return;
        CellBox view(array);
 
        threads_ = (needIsolines())  ? 4: 0;
@@ -1336,15 +1332,8 @@ void IsoPlot::isoline(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
  void IsoPlot::operator()(MatrixHandler& data, BasicGraphicsObjectContainer& parent)
 {
     prepare(data);
-    if ( legend_only_ ) {
-        if ( rainbow_ ) {
-            rainbowMethod_->set(*this);
-            rainbowMethod_->prepare(*levelSelection_, true);
-            setThicknessAndStyle();
-        }
-        return;
-    }
-    
+    if ( legend_only_ ) return;
+
     {
         Timer timer("contouring", "Time spent in contouring");
         isoline(data, parent);
@@ -1470,8 +1459,8 @@ void IsoPlot::visit(Data& data, LegendVisitor& legend) {
 
                     line->setColour((*rainbowMethod_)(*level));
                     line->setLineStyle(line_style(*level));
-                    line->setThickness(thickness(*level)*5);
-                    legend.add(new RainbowEntry(*level, line));
+                    line->setThickness(thickness(*level));
+                    legend.add(new LineEntry(*level, line));
                 }
                 break;
             }
